@@ -4,7 +4,7 @@ use warnings;
 use 5.006;
 
 package HTTP::BrowserDetect;
-$HTTP::BrowserDetect::VERSION = '2.08';
+$HTTP::BrowserDetect::VERSION = '3.00';
 use vars qw(@ALL_TESTS);
 
 # Operating Systems
@@ -1787,59 +1787,6 @@ sub _init_device {
         $device_tests->{$device} = 1;
     }
 
-    $device_tests->{mobile} = (
-        ( $browser_tests->{firefox} && index( $ua, "mobile" ) != -1 )
-            || ( $browser_tests->{ie}
-            && index( $ua, "windows phone" ) == -1
-            && index( $ua, "arm" ) != -1 )
-            || index( $ua, "windows phone" ) != -1
-            || index( $ua, "up.browser" ) != -1
-            || index( $ua, "nokia" ) != -1
-            || index( $ua, "alcatel" ) != -1
-            || index( $ua, "ericsson" ) != -1
-            || index( $ua, "sie-" ) == 0
-            || index( $ua, "wmlib" ) != -1
-            || index( $ua, " wap" ) != -1
-            || index( $ua, "wap " ) != -1
-            || index( $ua, "wap/" ) != -1
-            || index( $ua, "-wap" ) != -1
-            || index( $ua, "wap-" ) != -1
-            || index( $ua, "wap" ) == 0
-            || index( $ua, "wapper" ) != -1
-            || index( $ua, "blackberry" ) != -1
-            || index( $ua, "iemobile" ) != -1
-            || index( $ua, "palm" ) != -1
-            || index( $ua, "smartphone" ) != -1
-            || index( $ua, "windows ce" ) != -1
-            || index( $ua, "palmsource" ) != -1
-            || index( $ua, "iphone" ) != -1
-            || index( $ua, "ipod" ) != -1
-            || index( $ua, "ipad" ) != -1
-            || ( index( $ua, "opera mini" ) != -1
-            && index( $ua, "tablet" ) == -1 )
-            || index( $ua, "htc_" ) != -1
-            || index( $ua, "symbian" ) != -1
-            || index( $ua, "webos" ) != -1
-            || index( $ua, "samsung" ) != -1
-            || index( $ua, "samsung" ) != -1
-            || index( $ua, "zetor" ) != -1
-            || index( $ua, "android" ) != -1
-            || index( $ua, "symbos" ) != -1
-            || index( $ua, "opera mobi" ) != -1
-            || index( $ua, "fennec" ) != -1
-            || index( $ua, "obigo" ) != -1
-            || index( $ua, "opera tablet" ) != -1
-            || index( $ua, "rim tablet" ) != -1
-            || ( index( $ua, "bb10" ) != -1
-            && index( $ua, "mobile" ) != -1 )
-            || $device_tests->{psp}
-            || $device_tests->{dsi}
-            || $device_tests->{'n3ds'}
-            || index( $ua, "googlebot-mobile" ) != -1
-            || index( $ua, "msnbot-mobile" ) != -1
-            || index( $ua, "bingbot-mobile" ) != -1
-    );
-
     $device_tests->{tablet} = (
         index( $ua, "ipad" ) != -1
             || ( $browser_tests->{ie}
@@ -1872,6 +1819,61 @@ sub _init_device {
             || index( $ua, "hp-tablet" ) != -1
     );
 
+    if ( !$device_tests->{tablet} ) {
+        $device_tests->{mobile} = (
+            ( $browser_tests->{firefox} && index( $ua, "mobile" ) != -1 )
+                || ( $browser_tests->{ie}
+                && index( $ua, "windows phone" ) == -1
+                && index( $ua, "arm" ) != -1 )
+                || index( $ua, "windows phone" ) != -1
+                || index( $ua, "up.browser" ) != -1
+                || index( $ua, "nokia" ) != -1
+                || index( $ua, "alcatel" ) != -1
+                || index( $ua, "ericsson" ) != -1
+                || index( $ua, "sie-" ) == 0
+                || index( $ua, "wmlib" ) != -1
+                || index( $ua, " wap" ) != -1
+                || index( $ua, "wap " ) != -1
+                || index( $ua, "wap/" ) != -1
+                || index( $ua, "-wap" ) != -1
+                || index( $ua, "wap-" ) != -1
+                || index( $ua, "wap" ) == 0
+                || index( $ua, "wapper" ) != -1
+                || index( $ua, "blackberry" ) != -1
+                || index( $ua, "iemobile" ) != -1
+                || index( $ua, "palm" ) != -1
+                || index( $ua, "smartphone" ) != -1
+                || index( $ua, "windows ce" ) != -1
+                || index( $ua, "palmsource" ) != -1
+                || index( $ua, "iphone" ) != -1
+                || index( $ua, "ipod" ) != -1
+                || index( $ua, "ipad" ) != -1
+                || ( index( $ua, "opera mini" ) != -1
+                && index( $ua, "tablet" ) == -1 )
+                || index( $ua, "htc_" ) != -1
+                || index( $ua, "symbian" ) != -1
+                || index( $ua, "webos" ) != -1
+                || index( $ua, "samsung" ) != -1
+                || index( $ua, "samsung" ) != -1
+                || index( $ua, "zetor" ) != -1
+                || index( $ua, "android" ) != -1
+                || index( $ua, "symbos" ) != -1
+                || index( $ua, "opera mobi" ) != -1
+                || index( $ua, "fennec" ) != -1
+                || index( $ua, "obigo" ) != -1
+                || index( $ua, "opera tablet" ) != -1
+                || index( $ua, "rim tablet" ) != -1
+                || ( index( $ua, "bb10" ) != -1
+                && index( $ua, "mobile" ) != -1 )
+                || $device_tests->{psp}
+                || $device_tests->{dsi}
+                || $device_tests->{'n3ds'}
+                || index( $ua, "googlebot-mobile" ) != -1
+                || index( $ua, "msnbot-mobile" ) != -1
+                || index( $ua, "bingbot-mobile" ) != -1
+        );
+    }
+
     if ( $browser_tests->{obigo} && $ua =~ /^(mot-[^ \/]+)/ ) {
         $device_string = substr $self->{user_agent}, 0, length $1;
         $device_string =~ s/^MOT-/Motorola /i;
@@ -2467,7 +2469,7 @@ HTTP::BrowserDetect - Determine Web browser, version, and platform from an HTTP
 
 =head1 VERSION
 
-version 2.08
+version 3.00
 
 =head1 SYNOPSIS
 
@@ -2634,7 +2636,12 @@ format is the same as for the browser_version() functions.
 
 =head2 mobile()
 
-Returns true if the browser appears to belong to a handheld device.
+Returns true if the browser appears to belong to a mobile phone or
+similar device (i.e. one small enough that the mobile version of a
+page is probably preferable over the desktop version).
+
+In previous versions, tablet devices sometimes had mobile() return
+true. They are now mutually exclusive.
 
 =head2 tablet()
 
@@ -3205,6 +3212,8 @@ Atsushi Kato
 
 Marco Fontani
 
+Nicolas Doye
+
 =head1 TO DO
 
 POD coverage is not 100%.
